@@ -1678,7 +1678,7 @@ our %exceed = (
     'whois.nic.uk' => 'and will be replenished',
     'whois.networksolutions.com' => 'contained within a list of IP addresses that may have failed',
     'whois.worldsite.ws' => 'You exceeded the maximum',
-    'whois.tucows.com'  => 'Maximum Daily connection limit reached',
+    'whois.tucows.com'  => '(Maximum Daily connection limit reached|exceeded maximum connection limit)',
     'whois.centralnic.com'  => 'Query rate of \\d+',
     'whois.pir.org'  => 'WHOIS LIMIT EXCEEDED',
     'whois.nic.ms'   => 'Look up quota exceeded',
